#!/usr/bin/perl

###############################################################################
###############################################################################
# WebAPP NE (Network Edition) - Web Automated Perl Portal                     #
#-----------------------------------------------------------------------------#
# mods/calendar/sidebar.cgi                                                   #
# Calendar Mod                                                                #
# Based on Mod for WebAPP created by Ted Loomos (tloomos@pbs-inc.net),        #
# based on the verysimple organizer suite:                                    #
# ########################################################################### #
# Copyright (c) 2001 Jason M. Hinkle. All rights reserved. This script is
# free software; you may redistribute it and/or modify it under the same
# terms as Perl itself.
# For more information see: http://www.verysimple.com/scripts/
# LEGAL DISCLAIMER:
# This software is provided as-is.  Use it at your own risk.  The
# author takes no responsibility for any damages or losses directly
# or indirectly caused by this software.
# ########################################################################### #
# Version History - Ted Loomos                                                #
# 0.0.1 - 06/09/02 - Initial script created                                   #
# 0.0.2 - 06/24/02 - Cleaned up code and fixed minor bugs                     #
# 0.0.3 - 07/13/02 - Modified sidebar.cgi so it can be used on the left side  #
# To Do: remove font tags and add styles                                      #
#                                                                             #
# ******************************************************************          #
# W3C Validation for WebAPP v0.9.9.2 by: Jos Brown (www.bantychick.com)       #
# Show Event Dates Background Color by: Jos                                   #
# Style Sheet Integration for WebAPP v0.9.9.3 by: Jos                         #
# American or European Dates Format Options for WebAPP NE v0.9.9.3.4 by: Jos  #
# ******************************************************************          #
#                                                                             #
# Modified: 23 May, 25 June, 15 Aug 2006 by Jos                               #
###############################################################################
###############################################################################

$| = 1;
use CGI::Carp qw(fatalsToBrowser);

BEGIN {
##--------------------------------------------------------------
## If you are not using standard folder locations, the following
## line may need to be changed to match your installation
##--------------------------------------------------------------
	require "$scriptdir/mods/calendar/data/calendar.cfg";
#	require "$datadir/calendar/calendar.cfg"; # future integration
##--------------------------------------------------------------
## Nothing below this point should require modification
##--------------------------------------------------------------
	if (-e "$cm_langDir/$userlang") {require "$cm_langDir/$userlang"} else {require "$cm_langDir/$cm_langFileName"}

	push(@INC,$cm_scriptDir);
}

use vsDB;

###########################
sub cal_displaySidebarCal {
###########################

	if (!defined &boxtop) { # old themes compatibility
		print qq~<tr><td>~;
	}

	my ($dataFile) = "$cm_dataDir/$cm_eventsFileName";

	my ($month)   = abs($mon_num); # from the global (has zero prepended)
	my ($day)     = abs($mday); # from the global (has zero prepended)

	my ($objDB) = new vsDB(
		file => $dataFile,
		delimiter => $cm_delimiter,
	);

	if (!$objDB->Open) {print $objDB->LastError;$objLock->unlock($dataFile);&die;};

	# figure out which day to highlight on the calendar
	my ($highlightDate) = $year . "." . $month . "." . $day;

	my $style = "";
	my $calstyle = "";
	if ($cmsb_headFontStyle) {
		$style = " style=\"$cmsb_headFontStyle\"";
	}
	if ($cmsb_borderStyle) {
		$calstyle = " style=\"$cmsb_borderStyle\"";
	}

	print qq~<div class="calhead"><a href="$cm_scriptUrl?vsSD=1&amp;vsMonth=$month&amp;vsYear=$year"$style>$months[$month-1] $year</a></div>
<table align="center" cellpadding="0" cellspacing="0" class="calbody" border="$cmsb_borderWidth"
 summary="events this month"$calstyle>
~;

	&PrintMonth1($month,$year,$objDB,$highlightDate);

	print qq~</table>
~;

	if (!defined &boxbottom) { # old themes compatibility
		print qq~</td></tr>~;
	}

	1;

}

#################
sub PrintMonth1 {
#################

    my ($month, $year, $objMyDb, $highlightDate) = @_;

    my ($firstDay,$numDays,$numWeeks,@weekdays) = &GetMonthInfo1($month,$year);

    my ($temp, $thisDate, $style, $class, $height, $datedisp);
    my $dayCount = 0;
    my $weekDayCount = 0;

	# get the styling strings (for backwards compatibility with old calendar.cfg styles) - Jos
	my $daystyle = "";
	if ($cmsb_dayHeadCellStyle) { $daystyle .= "$cmsb_dayHeadCellStyle;"; }
	if ($cmsb_dayHeadFontStyle) { $daystyle .= " $cmsb_dayHeadFontStyle"; }
	if ($daystyle) { $daystyle = " style=\"$daystyle\""; }
	my $selstyle = "";
	if ($cmsb_selFontStyle) { $selstyle .= "$cmsb_selFontStyle;"; }
	if ($cmsb_selCellStyle) { $selstyle .= " $cmsb_selCellStyle"; }
	if ($selstyle) { $selstyle = " style=\"$selstyle\""; }
	my $stdstyle = "";
	if ($cmsb_stdFontStyle) { $stdstyle .= "$cmsb_stdFontStyle;"; }
	if ($cmsb_stdCellStyle) { $stdstyle .= " $cmsb_stdCellStyle"; }
	if ($stdstyle) { $stdstyle = " style=\"$stdstyle\""; }
	my $emptystyle = "";
	if ($cmsb_emptyCellStyle) { $emptystyle = " style=\"$cmsb_emptyCellStyle\""; }

	# print the days of the week
	print "<tr>\n";

	print "<td width=\"$cmsb_cellSize\" height=\"$cmsb_cellSize\"$daystyle>$weekdays[0]</td>\n"; # set height first cell only

	foreach $temp (@weekdays[1..$#weekdays]) {
		print "<td width=\"$cmsb_cellSize\"$daystyle>$temp</td>\n";
	}
	print "</tr>\n";

	for (my $cellCount = 1;$cellCount <= $numWeeks; $cellCount++) {
		print "<tr>\n";

		foreach $temp (@daysAbbrev) {
			$style = "";
			$class = "";
			$datedisp = "";
			$height = "";
			if ($temp eq $daysAbbrev[0]) {
				$height = " height=\"$cmsb_cellSize\"";
			} # height only on first cell in row - Jos

		    if (($dayCount > $firstDay-1) && ($weekDayCount < $numDays)) { # if not empty
				$weekDayCount++;

				$thisDate = $year . "." . $month . "." . $weekDayCount;

				if ($thisDate eq $highlightDate) { # today
				    $style = $selstyle;
					$class = " class=\"caltoday\"";
				} else { # any day
				    $style = $stdstyle;
				}

			    $objMyDb->RemoveFilter;
			    $objMyDb->Filter("DATE","eq",$thisDate);
			    if ($userrank ne $root) {
				    if ($username eq $anonuser) {
				    	$objMyDb->Filter("APPROVED","eq","1");
				    	$objMyDb->Filter("OWNER","eq",$cal_msg{'008'});
			    	} else {
				    	$objMyDb->Filter("APPROVED","eq","1");
					    $objMyDb->Filter("OWNER","eq",$cal_msg{'008'});
				    	$objMyDb->Filter("OWNER","eq",$username,1);
					    $objMyDb->Filter("DATE","eq",$thisDate);
			    	}
			    }

				if ($objMyDb->EOF) {
					$datedisp = "$weekDayCount";
				} else {
					$datedisp = "<a href=\"$cm_scriptUrl?vsSD=1&amp;vsMonth=$month&amp;vsYear=$year&amp;vsDay=$weekDayCount\">$weekDayCount</a>";
					$class = " class=\"calhigh\""; # cell style
				}

		    } else {
				$style = $emptystyle;
				$datedisp = "&nbsp;"; # empty
		    }
			print "<td align=\"center\"$height$style$class>$datedisp</td>\n";
		    $dayCount++;
		}
		print "</tr>\n";
    }
}

###################
sub GetMonthInfo1 {
###################

    my $month = shift || 1;
    my $year  = shift || 2002;

    my($firstDow,$numDays);

    require Time::Local;

    # convert user input into approp format for processing
    --$month;
    $year -= 1900;

    # figure out following month & year
    my $nmonth = $month + 1;
    my $nyear  = $year;
    if ($nmonth > 11) {
       $nmonth = 0;
	   $nyear++;
    }

    # ready to grab first day of the month (0 based array)
    $firstDow  = (localtime(Time::Local::timelocal(0,0,0,1,$month,$year)))[6];
    # numDays is one day prior to 1st of month after
    $numDays = (localtime(Time::Local::timelocal(0,0,0,1,$nmonth,$nyear) - 60*60*24))[3];

	# check for first day of week - Jos
	my @weekdays = @daysAbbrev;
	if ($user_check_date eq 'european') {
		$firstDow -= 1;
		$firstDow += 7 if ($firstDow < 0);
		my $lastday = shift(@weekdays);
		push(@weekdays, $lastday);
	}

    # figure out the number of weeks the month spans across
    my $numWeeks = ($numDays + $firstDow) / 7;
    $numWeeks = int($numWeeks) + 1 unless ($numWeeks == int($numWeeks));

	return ($firstDow,$numDays,$numWeeks,@weekdays);
}

1;